package com.pcloud.book.mq.topic;

import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;

import com.pcloud.usercenter.common.enums.ResourceEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.pcloud.book.base.exception.BookBizException;
import com.pcloud.book.book.biz.BookAdviserBiz;
import com.pcloud.common.exceptions.BizException;
import com.pcloud.usercenter.system.entity.ExtraSetting;

/**
 * @描述： 选择默认渠道
 */
@Component("chooseDefaultChannelListener")
public class ChooseDefaultChannelListener implements MessageListener {
    @Autowired
    private BookAdviserBiz bookAdviserBiz;
    private static final Logger LOGGER = LoggerFactory.getLogger(ChooseDefaultChannelListener.class);

    /**
     * 选择默认渠道Topic
     */
    @Override
    public void onMessage(Message message) {
        if (!(message instanceof ObjectMessage)) {
            throw new BookBizException(BookBizException.CONSUMER_TOPIC_ERROR, "【选择默认渠道】类型转换错误");
        }
        // 转换消息实体
        ExtraSetting extraSetting = null;
        try {
            ObjectMessage om = (ObjectMessage) message;
            extraSetting = (ExtraSetting) om.getObject();
        } catch (Exception e) {
            LOGGER.error("【选择默认渠道】消费topic,<ERROR>:" + e.getMessage(), e);
            return;
        }
        if (extraSetting == null) {
            return;
        }
        try {
            if (!ResourceEnum.APP.code.equals(extraSetting.getResourceId())) {
                bookAdviserBiz.createDefaultBook(extraSetting.getOptionTarget(), extraSetting.getPartyId());
            }
        } catch (BizException e) {
            LOGGER.warn("生成默认图书失败,<ERROR>:" + e.getMessage(), e);
            return;
        } catch (Exception e) {
            LOGGER.error("生成默认图书失败,<ERROR>:" + e.getMessage(), e);
            return;
        }
    }
}
